@@ -9,7 +9,7 @@ with open(path.join(settings.BASE_DIR, '..', 'README.md'), encoding='utf-8') as
 
 setup(
     name='garpix_jira',
-    version='1.0.0',
+    version='1.2.1',
     description='',
     long_description=long_description,
     url='https://github.com/garpixcms/garpix_jira',
@@ -30,7 +30,8 @@ setup(
     include_package_data=True,
     zip_safe=False,
     install_requires=[
-        'garpixcms >= 2.0.2',
+        'django >= 3.1',
+        'jira >= 3.0.1',
     ],
 )
 
